@@ -599,7 +599,7 @@ class ESN:
             self.n_output = self.n_input 
         
         #adjust xrows as according to changed n_input
-        if self.extendedStateStyle == _EXNTENDED_STATE_STYLES[0]:
+        if self.extendedStateStyle == _EXTENDED_STATE_STYLES[0]:
             self.xrows = int(1+self.n_reservoir+self.n_input)          
         
         study_dict['n_input'] = n_input
@@ -611,7 +611,7 @@ class ESN:
         self.n_reservoir = n_reservoir
 
         #adjust xrows as according to changed n_reservoir
-        if self.extendedStateStyle == _EXNTENDED_STATE_STYLES[0]:
+        if self.extendedStateStyle == _EXTENDED_STATE_STYLES[0]:
             self.xrows = int(1+self.n_reservoir+self.n_input)           
         else:
             self.xrows = int(1+2*self.n_reservoir)
@@ -734,7 +734,7 @@ class ESN:
         
         assert len(study_tuple) > 0,'study_tuple is empty. Did you forget to specify the study HP?'
 
-        study_dict  ={}
+        study_dict = {}
 
         for iparam, parameter in enumerate(study_tuple):
 
@@ -1100,17 +1100,17 @@ class ESN:
 
         HP_range_dict = {}
 
-        HP_range_dict['n_reservoir'] = (1e2,1e4)
-        HP_range_dict['leakingRate'] = (1e-3,1e0)
-        HP_range_dict['spectralRadius'] = (1e-3,1e1)
+        HP_range_dict['n_reservoir'] = (1e2,5e3)
+        HP_range_dict['leakingRate'] = (1e-2,1e0)
+        HP_range_dict['spectralRadius'] = (1e-3,2e0)
         HP_range_dict['reservoirDensity'] = (1e-2,1e0)
-        HP_range_dict['dataScaling'] = (1e-2,1e1)
-        HP_range_dict['regressionParameters'] = (1e-6,1e0)
+        HP_range_dict['dataScaling'] = (1e-2,5e0)
+        HP_range_dict['regressionParameter'] = (1e-6,1e1)
         HP_range_dict['bias_in'] = (1e-3,1e0)
         HP_range_dict['bias_out'] = (1e-3,1e0)
         HP_range_dict['outputInputScaling'] = (1e-3,1e0)
         HP_range_dict['inputScaling'] = (1e-2,1e1)
-        HP_range_dict['inputrDensity'] = (1e-2,1e0)
+        HP_range_dict['inputDensity'] = (1e-2,1e0)
         HP_range_dict['noiseLevel_in'] = (1e-6,1e0)
         HP_range_dict['noiseLevel_out'] = (1e-6,1e0)
         
