@@ -794,12 +794,12 @@ def ReadStudy(filepath: str, study_parameters: Union[list,tuple], nstudy: int =
                         Y_pred_val.append(np.array(G_study.get('y_pred_val')))
                         
 
-                mse_train.append(MSE_train)
-                mse_test.append(MSE_test)
-                mse_val.append(MSE_val)
+                mse_train.append(np.array(MSE_train))
+                mse_test.append(np.array(MSE_test))
+                mse_val.append(np.array(MSE_val))
                 
-                y_pred_test.append(Y_pred_test)
-                y_pred_val.append(Y_pred_val)
+                y_pred_test.append(np.array(Y_pred_test))
+                y_pred_val.append(np.array(Y_pred_val))
                 
                     
         config = CreateStudyConfigArray(study_parameters, study_dicts)
